@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
-from .generic import Manager, AllMixin
+from .generic import Manager, AllMixin, SyncMixin
 
 
-class LiveNotificationsManager(Manager, AllMixin):
+class LiveNotificationsManager(Manager, AllMixin, SyncMixin):
 
     state_name = 'LiveNotifications'
+    object_type = 'live_notification'
+    resource_type = 'live_notifications'
 
     def get_by_key(self, notification_key):
         """
@@ -23,7 +25,7 @@ class LiveNotificationsManager(Manager, AllMixin):
         self.state[self.state_name] = seq_no
         item = {
             'type': 'live_notifications_mark_as_read',
-            'timestamp': self.api.generate_timestamp(),
+            'uuid': self.api.generate_uuid(),
             'args': {
                 'seq_no': seq_no,
             },
