@@ -4,9 +4,6 @@ from .generic import Manager
 
 class UserManager(Manager):
 
-    def refresh(self):
-        return self.api.sync(resource_types=[])
-
     def update(self, **kwargs):
         """
         Updates the user data, and appends the equivalent request to the queue.
@@ -14,13 +11,30 @@ class UserManager(Manager):
         self.state['User'].update(kwargs)
         item = {
             'type': 'user_update',
-            'timestamp': self.api.generate_timestamp(),
+            'uuid': self.api.generate_uuid(),
             'args': kwargs,
         }
         self.queue.append(item)
 
-    def get(self):
-        return self.state['User']
+    def update_goals(self, **kwargs):
+        """
+        Update the user's karma goals.
+        """
+        item = {
+            'type': 'update_goals',
+            'uuid': self.api.generate_uuid(),
+            'args': kwargs,
+        }
+        self.queue.append(item)
+
+    def sync(self):
+        return self.api.sync(resource_types=['user'])
+
+    def get(self, key=None, default=None):
+        ret = self.state['User']
+        if key is not None:
+            ret = ret.get(key, default)
+        return ret
 
     def get_id(self):
         return self.state['UserId']
